@@ -4,7 +4,7 @@
 - License: MIT
 """
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __all__ = ["BasicDweetError", "dweet_for", "get_latest_dweet_for", "get_dweets_for"]
 
 import json
@@ -21,8 +21,8 @@ class BasicDweetError(Exception):
     pass
 
 
-def _request(method, url, **kwargs):
-    url = BASE_URL + url
+def _request(method, url, base_url=BASE_URL, **kwargs):
+    url = base_url.rstrip("/") + "/" + url.lstrip("/")
 
     request_func = getattr(requests, method)
     response = request_func(url, **kwargs)
@@ -34,20 +34,21 @@ def _request(method, url, **kwargs):
     return response_json["with"]
 
 
-def dweet_for(thing_name, payload):
+def dweet_for(thing_name, payload, base_url=BASE_URL):
     data = json.dumps(payload)
     headers = {"Content-type": "application/json"}
     return _request(
         "post",
         f"/dweet/for/{thing_name}",
+        base_url=base_url,
         data=data,
         headers=headers,
     )
 
 
-def get_latest_dweet_for(thing_name):
-    return _request("get", f"/get/latest/dweet/for/{thing_name}")
+def get_latest_dweet_for(thing_name, base_url=BASE_URL):
+    return _request("get", f"/get/latest/dweet/for/{thing_name}", base_url=base_url)
 
 
-def get_dweets_for(thing_name):
-    return _request("get", f"/get/dweets/for/{thing_name}")
+def get_dweets_for(thing_name, base_url=BASE_URL):
+    return _request("get", f"/get/dweets/for/{thing_name}", base_url=base_url)
